@@ -1,10 +1,8 @@
 """Wrapper for Google OAuth2 API."""
-import googleapiclient.discovery
 import oauth2client.client
 from oauth2client.file import Storage
 
 from . import console
-from . import browser
 
 def _get_credentials_interactively(flow, storage, get_code_callback):
     """Return the credentials asking the user."""
@@ -17,12 +15,12 @@ def _get_credentials_interactively(flow, storage, get_code_callback):
         credential.set_store(storage)
         return credential
 
-def get_credentials(client_secrets_file, credentials_file, 
-        scope, get_code_callback=console.get_code):
+def get_credentials(client_secrets_file, credentials_file,
+                    scope, get_code_callback=console.get_code):
     """Return the user credentials from the file or run the interactive flow."""
     get_flow = oauth2client.client.flow_from_clientsecrets
     flow = get_flow(client_secrets_file, scope=scope)
-    storage = oauth2client.file.Storage(credentials_file)
+    storage = Storage(credentials_file)
     existing_credentials = storage.get()
     if existing_credentials and not existing_credentials.invalid:
         return existing_credentials
